@@ -1,14 +1,16 @@
 #' Data for examples
 #'
-#' Supporting data sets to use in the examples. They will be used in the
+#' Supporting data sets to use in the examples. Some will be used in the
 #' examples. example.ammonite.svg and log.loop.tex are meant to generate their
-#' respective .svg and .tex files.
+#' respective .svg and .tex files. Others are used in the article (to be
+#' published soon).
 #'
 #'\describe{
 #'   \item{\strong{Litholog drawing data}}{bed.example, boundary.example,
 #'   example.ammonite, example.ammonite.svg, example.belemnite, example.breccia,
 #'   example.HB2000.svg, example.lense, example.liquefaction, fossil.example,
 #'   proxy.example, proxy.example.litho}
+#'   \item{\strong{Time-Series}}{irreg.example}
 #'   \item{\strong{Magnetostratigraphical data}}{chron.example}
 #'   \item{\strong{Litholog exportation script}}{log.loop.tex}
 #'   \item{\strong{Oriented data}}{zeq_example}
@@ -63,6 +65,10 @@ NULL
 #' @name example.liquefaction
 NULL
 
+#' @rdname StratigrapheR.examples
+#' @name irreg.example
+NULL
+
 #' @rdname StratigrapheR.examples
 #' @name fossil.example
 NULL
